@@ -3,14 +3,15 @@ Main interface for cloudhsm service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.cloudhsm import (
+    from mypy_boto3_cloudhsm import (
         Client,
         CloudHSMClient,
         ListHapgsPaginator,
         ListHsmsPaginator,
         ListLunaClientsPaginator,
-        )
+    )
 
     session = boto3.Session()
 
@@ -20,8 +21,9 @@ Usage::
     list_hapgs_paginator: ListHapgsPaginator = client.get_paginator("list_hapgs")
     list_hsms_paginator: ListHsmsPaginator = client.get_paginator("list_hsms")
     list_luna_clients_paginator: ListLunaClientsPaginator = client.get_paginator("list_luna_clients")
+    ```
 """
-from mypy_boto3_cloudhsm.client import CloudHSMClient as Client, CloudHSMClient
+from mypy_boto3_cloudhsm.client import CloudHSMClient, CloudHSMClient as Client
 from mypy_boto3_cloudhsm.paginator import (
     ListHapgsPaginator,
     ListHsmsPaginator,
